@@ -76,7 +76,7 @@ class LimooDriver:
                         previous_slc = self._successful_login_count
         return wrapper
 
-    def __init__(self, limoo_url, bot_username, bot_password, secure=True):
+    def __init__(self, limoo_url, bot_username, bot_password, secure=True, max_requests_retry=2):
         # Catch a relatively common mistake and report an informative error
         assert not limoo_url.startswith(('http://', 'https://')), (
             'The URL of the Limoo server should not start with'
@@ -98,6 +98,7 @@ class LimooDriver:
         self._authlock = asyncio.Lock()
         self._listen_task = None
         self._event_handler = lambda event: None
+        self._max_requests_retry = max_requests_retry
         self.conversations = Conversations(self)
         self.files = Files(self)
         self.messages = Messages(self)
@@ -124,6 +125,10 @@ class LimooDriver:
     async def _execute_api_post(self, endpoint, body):
         return await self._execute_json_request('POST', endpoint, body=body)
 
+    @_with_auth
+    async def _execute_api_delete(self, endpoint):
+        return await self._execute_json_request('DELETE', endpoint)
+
     async def _execute_json_request(self, method, endpoint, *, body=None):
         return await self._get_json_body(await self._execute_request(method, f'{self._api_url_prefix}/{endpoint}', json=body))
 
@@ -143,10 +148,16 @@ class LimooDriver:
         return StreamReader(await self._execute_request('GET', f'{self._fileop_url}?mode=download&{params}'))
 
     async def _execute_request(self, method, url, *, data=None, json=None):
-        try:
-            response = await self._client_session.request(method, url, data=data, json=json, params={"is_bot": "true"})
-        except ClientConnectionError as ex:
-            raise LimooError('Connection Error') from ex
+        for retry_attempts in range(self._max_requests_retry):
+            try:
+                response = await self._client_session.request(method, url, data=data, json=json, params={"is_bot": "true"})
+                break
+            except ClientConnectionError as ex:
+                _LOGGER.error(f'Connection Error for sending request: {ex}')
+                await asyncio.sleep(2 + 2 * retry_attempts)
+                _LOGGER.info(f'Retry to send request, attempt number: {retry_attempts + 1}')
+        else:
+            raise LimooError('Connection Error')
         status = response.status
         if status < 400:
             return response
